import { CurrentQuestion, NextQuestionResponse, QuestionOption, QuizResultsResponse, QuizSharedResultsData, QuizResultsConfigResponse } from '../../types';
import type { QuizLocalReducerState } from './quizLocalReducer';
export declare enum QuestionTypes {
    OpenText = "open",
    Cover = "cover",
    SingleSelect = "single",
    MultipleSelect = "multiple",
    Next = "next",
    Skip = "skip",
    Back = "back",
    Reset = "reset",
    Hydrate = "hydrate",
    Complete = "complete"
}
export interface QuestionAnswer<Value> {
    questionId: number;
    input: Value;
}
export type SelectQuestionPayload = QuestionAnswer<Omit<QuestionOption, 'attribute' | 'images'>[]>;
export type OpenTextQuestionPayload = QuestionAnswer<string>;
export type CoverQuestionPayload = QuestionAnswer<string>;
interface Action<Type, Payload = {}> {
    type: Type;
    payload?: Payload;
}
export type ActionAnswerInputQuestion = Action<QuestionTypes.OpenText, OpenTextQuestionPayload> | Action<QuestionTypes.SingleSelect, SelectQuestionPayload> | Action<QuestionTypes.MultipleSelect, SelectQuestionPayload> | Action<QuestionTypes.Cover, CoverQuestionPayload>;
export type ActionAnswerQuestion = ActionAnswerInputQuestion | Action<QuestionTypes.Next, CurrentQuestion> | Action<QuestionTypes.Skip, CurrentQuestion> | Action<QuestionTypes.Back, CurrentQuestion> | Action<QuestionTypes.Reset> | Action<QuestionTypes.Complete> | Action<QuestionTypes.Hydrate, Partial<QuizLocalReducerState>>;
export declare enum QuizAPIActionTypes {
    SET_IS_LOADING = 0,
    SET_IS_ERROR = 1,
    SET_QUIZ_RESULTS = 2,
    SET_CURRENT_QUESTION = 3,
    RESET_QUIZ = 4,
    SET_QUIZ_SHARED_RESULTS = 5,
    SET_QUIZ_RESULTS_CONFIG = 6,
    SET_QUIZ_RESULTS_CONFIG_ERROR = 7
}
export type ActionSetIsLoading = Action<QuizAPIActionTypes.SET_IS_LOADING>;
export type ActionSetIsError = Action<QuizAPIActionTypes.SET_IS_ERROR>;
export type ActionSetQuizResults = Action<QuizAPIActionTypes.SET_QUIZ_RESULTS, {
    quizResults: QuizResultsResponse;
}>;
export type ActionSetQuizSharedResults = Action<QuizAPIActionTypes.SET_QUIZ_SHARED_RESULTS, {
    quizResults: QuizSharedResultsData;
}>;
export type ActionSetCurrentQuestion = Action<QuizAPIActionTypes.SET_CURRENT_QUESTION, {
    quizCurrentQuestion: NextQuestionResponse;
    quizSessionId?: string;
    quizVersionId?: string;
}>;
export type ActionResetQuiz = Action<QuizAPIActionTypes.RESET_QUIZ>;
export type ActionSetQuizResultsConfig = Action<QuizAPIActionTypes.SET_QUIZ_RESULTS_CONFIG, {
    quizResultsConfig: QuizResultsConfigResponse;
}> | Action<QuizAPIActionTypes.SET_QUIZ_RESULTS_CONFIG_ERROR>;
export type ActionQuizAPI = ActionSetIsLoading | ActionSetIsError | ActionSetQuizResults | ActionSetCurrentQuestion | ActionResetQuiz | ActionSetQuizSharedResults | ActionSetQuizResultsConfig;
export {};
